@@ -231,7 +231,7 @@ class Disk(MatchingPartedMixin, Retryable, object):
 
     def force_kernel_to_re_read_partition_table(self):
         from infi.execute import execute
-        execute(["partprobe"]).wait()
+        execute(["partprobe", format(self._device_access_path)]).wait()
 
     @retry_func(WaitAndRetryStrategy(max_retries=5, wait=5))
     def _execute_mkfs(self, filesystem_name, partition_access_path):
